/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "UCQSearchDialog.h"

/**
 * \brief Sets up the gui.
 *
 * \param parent Pointer to the parent QWidget.
 * \param sc Pointer to SearchController to use.
 */
UCQSearchDialog::UCQSearchDialog(QWidget *parent, SearchController * sc) :
	QDialog(parent) {
	ui_.setupUi(this);
	QStringList selections;
	selections << QString(tr("Search in block"));
	selections << QString(tr("Search in all blocks"));
	selections << QString(tr("Search in the file"));

	ui_.comboBoxTable->insertItems(0, selections);
	ui_.comboBoxTable->repaint();
	// Mac search dialog behavior
#ifdef Q_WS_MAC
	Qt::WindowFlags flags = windowFlags();
	flags ^= Qt::Dialog;
	flags |= Qt::Window | Qt::CustomizeWindowHint | Qt::WindowSystemMenuHint
	| Qt::WindowStaysOnTopHint;
	setWindowFlags(flags);
#endif

	// hide collation-level selection
	ui_.line->setVisible(false);
	ui_.labelLvl->setVisible(false);
	ui_.checkLvl1->setVisible(false);
	ui_.checkLvl2->setVisible(false);
	ui_.checkLvl3->setVisible(false);
	ui_.checkLvl4->setVisible(false);
	ui_.line_2->setVisible(false);

	sc_ = sc;
	searchPerformed_ = false;
}

/**
 * \brief Slot for the next button, calls next() on the SearchController and
 *        updates the dialog.
 * \see SearchController::next()
 */
void UCQSearchDialog::on_buttonNext_clicked() {
	sc_->next();
	updateSearchDialog();
}

/**
 * \brief Slot for the previous button, calls previous() on the SearchController
 *        and updates the dialog.
 * \see SearchController::previous()
 */
void UCQSearchDialog::on_buttonPrevious_clicked() {
	sc_->previous();
	updateSearchDialog();
}

/**
 * \brief Slot for the search button, calls search() on the SearchController and
 *        updates the dialog.
 * \see SearchController::search()
 */
void UCQSearchDialog::on_buttonSearch_clicked() {
	QList<bool> lvls;
	lvls << ui_.checkLvl1->isChecked();
	lvls << ui_.checkLvl2->isChecked();
	lvls << ui_.checkLvl3->isChecked();
	lvls << ui_.checkLvl4->isChecked();

	if(ui_.comboBoxTable->currentIndex()== 0) {
		if (sc_->search(ui_.searchLineEdit->text(),
				ui_.checkBoxCodepoint->isChecked(),
				ui_.checkBoxCollation->isChecked(),
				ui_.checkBoxComment->isChecked(),
				ui_.checkBoxLinestring->isChecked(),
				ui_.checkBoxCaseSensitivity->isChecked(),
				ui_.checkBoxRegEx->isChecked(), lvls)) {
			sc_->next();
		}

	}
	else if(ui_.comboBoxTable->currentIndex()== 1)  {
		sc_->setAllBlocks();

		if (sc_->search(ui_.searchLineEdit->text(),
				ui_.checkBoxCodepoint->isChecked(),
				ui_.checkBoxCollation->isChecked(),
				ui_.checkBoxComment->isChecked(),
				ui_.checkBoxLinestring->isChecked(),
				ui_.checkBoxCaseSensitivity->isChecked(),
				ui_.checkBoxRegEx->isChecked(), lvls)) {
			sc_->next();
		}

	}
	else if(ui_.comboBoxTable->currentIndex()== 2) {
		sc_->searchTable(ui_.searchLineEdit->text(),
						ui_.checkBoxCodepoint->isChecked(),
						ui_.checkBoxCollation->isChecked(),
						ui_.checkBoxComment->isChecked(),
						ui_.checkBoxLinestring->isChecked(),
						ui_.checkBoxCaseSensitivity->isChecked(),
						ui_.checkBoxRegEx->isChecked(), lvls);



	}


	searchPerformed_ = true;
	updateSearchDialog();
}

/**
 * \brief Slot for Select all button, calls selectAll on SearchController and
 *        updates the dialog.
 */
void UCQSearchDialog::on_buttonSelectAll_clicked() {
	sc_->selectAll();
	updateSearchDialog();
}

/**
 * \brief Shows the dialog with the state of the SearchController.
 */
void UCQSearchDialog::show() {
	ui_.searchLineEdit->setText(sc_->getSearchtext());
	ui_.checkBoxRegEx->setChecked(sc_->getRegexp());
	ui_.checkBoxComment->setChecked(sc_->getComment());
	ui_.checkBoxCodepoint->setChecked(sc_->getCodepoint());
	ui_.checkBoxCollation->setChecked(sc_->getCollation());
	ui_.checkBoxCaseSensitivity->setChecked(sc_->getCasesensitivity());

	if (sc_->getLvls().count() > 0) {
		ui_.checkLvl1->setChecked(sc_->getLvls().at(0));
		ui_.checkLvl2->setChecked(sc_->getLvls().at(1));
		ui_.checkLvl3->setChecked(sc_->getLvls().at(2));
		ui_.checkLvl4->setChecked(sc_->getLvls().at(3));
	}
	updateSearchDialog();
	QDialog::show();
}

/**
 * \brief Dis-/Enables elements of the gui according to the state of the
 *        SearchController.
 */
void UCQSearchDialog::updateSearchDialog() {
	ui_.buttonNext->setEnabled(sc_->hasNext());
	ui_.buttonPrevious->setEnabled(sc_->hasPrevious());
	ui_.buttonSelectAll->setEnabled(!sc_->isEmpty());
	if (!sc_->isEmpty()) {
		ui_.hitsLabel->setText(QString::number(sc_->numberOfHits()) + " " + tr(
				"Hits"));
	} else {
		if (searchPerformed_)
			ui_.hitsLabel->setText(" 0 " + tr("Hits"));
		else {
			ui_.hitsLabel->setText("");
		}
	}
}
