/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef UCQSEARCHDIALOG_H
#define UCQSEARCHDIALOG_H

#include <QtGui/QDialog>
#include "ui/ui_ucsearch.h"
#include "controller/SearchController.h"

/**
 * \class UCQSearchDialog
 * \brief GUI for the SearchController.
 *
 * This dialog is a GUI for the search in the displayed table.
 * It uses the SearchController to search and represents its state.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see SearchController
 */
class UCQSearchDialog: public QDialog
{

Q_OBJECT

public:
    UCQSearchDialog ( QWidget* = 0, SearchController* = 0 );

    void show ();

private:
    void updateSearchDialog ();
    /**
     * \brief Ui object.
     */
    Ui::UCQSearchDialog ui_;
    /**
     * \brief SearchController to use.
     */
    SearchController* sc_;
    /**
     * \brief Is set to true when the user performs a search.
     */
    bool searchPerformed_;

protected slots:
    void on_buttonSearch_clicked    ();
    void on_buttonNext_clicked      ();
    void on_buttonPrevious_clicked  ();
    void on_buttonSelectAll_clicked ();
};

#endif // UCQSEARCHDIALOG_H
