/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "LuaWrapper.h"

/**
 * \brief Creates the wrapper object.
 *
 * \param L The lua interpreter state.
 * \param wrapperName The name of this wrapper.
 */
LuaWrapper::LuaWrapper(lua_State* L, QString wrapperName){
	setWrapperName(wrapperName);

	if(lua_islightuserdata( L, 1) == 0){
		objectController_ = 0;
		luaL_error(L,QObject::tr("No controller object found.").toLatin1().data());
	}
	else{
		objectController_ = (Controller*) lua_touserdata( L, 1);
		if(!isController()){
	    	luaL_error(L,QObject::tr("Wrong controller object.").toLatin1().data());
		}
	}
}

/**
 * \brief Empty.
 */
LuaWrapper::~LuaWrapper (){
}

/**
 * \brief Returns true if the controller object is null.
 *
 * \return State of controller object.
 */
bool LuaWrapper::isNull(){
	return objectController_ == 0;
}

/**
 * \brief Returns true, if the wrapper is a controller.
 *
 * \return True, if the wrapper is a controller.
 */
bool LuaWrapper::isController(){
	return getWrapperName() == objectController_->getName();
}

/**
 * \brief Setter for the wrapper name.
 *
 * \param wrapperName The name for this wrapper.
 */
void LuaWrapper::setWrapperName(QString wrapperName){
	wrapperName_ = wrapperName;
}

/**
 * \brief Getter for the wrapper name.
 *
 * \return The name of this wrapper.
 */
QString LuaWrapper::getWrapperName() const{
	return wrapperName_;
}

